from zope.interface import implements
from archetypes.schemaextender.interfaces import IOrderableSchemaExtender
from archetypes.schemaextender.field import ExtensionField
from Products.Archetypes import atapi
from Products.Archetypes.utils import OrderedDict


class StringExtField(ExtensionField, atapi.StringField):
    """Selection Field for schemaextender
    """


class ThemeSelectionExtender(object):
    """Schema extender for Child Site Theme Selection.
    """

    fields = [
        StringExtField(
            'lineage_theme',
            schemata='settings',
            mode="w",
            write_permission="Manage portal",
            required=False,
            vocabulary_factory='plone.app.vocabularies.Skins',
            widget=atapi.SelectionWidget(
                label=u"Theme for Child-Site",
                description=u"Select a theme for the child site.",
            )
        ),
    ]

    implements(IOrderableSchemaExtender)

    def __init__(self, context):
        self.context = context

    def getFields(self):
        return self.fields

    def getOrder(self, original):
        neworder = OrderedDict()
        for schemata in original.keys():
            neworder[schemata] = original[schemata]
            if schemata == 'settings' \
               and 'lineage_theme' not in neworder['settings']:
                neworder['settings'].append('lineage_theme')
        return neworder



from Products.Five import BrowserView
from collective.lineage.interfaces import IChildSite


class ActionAvailableView(BrowserView):

    def __call__(self):
        return IChildSite.providedBy(self.context)



from zope.interface import alsoProvides
from .interfaces import ILineageThemingLayer


def apply_theme(obj, event):
    """Switch to the skin or theme selected for the child site.
    """
    alsoProvides(event.request, ILineageThemingLayer)
    field = obj.Schema().get('lineage_theme', None)
    if field is None:
        return
    theme = field.get(obj)
    if not theme:
        return
    obj.changeSkin(theme, event.request)



from setuptools import setup, find_packages
import os

version = '1.3'
shortdesc = "Lineage Addon: Theme Selection on Subsites"
longdesc = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()
longdesc += open(os.path.join(os.path.dirname(__file__), 'HISTORY.rst')).read()
longdesc += open(os.path.join(os.path.dirname(__file__), 'LICENSE.rst')).read()

setup(
    name='lineage.themeselection',
    version=version,
    description=shortdesc,
    long_description=longdesc,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Plone :: 4.1',
        'Framework :: Plone :: 4.2',
        'Framework :: Plone :: 4.3',
    ],
    keywords='',
    author='BlueDynamics Alliance',
    author_email='dev@bluedynamics.com',
    url=u'https://github.com/collective/lineage.themeselection',
    license='GNU General Public Licence',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    namespace_packages=['lineage', ],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'collective.lineage',
        'lineage.registry',
        'archetypes.schemaextender',
        'plone.app.theming',  # for plone 4.2
    ],
    entry_points="""
    [z3c.autoinclude.plugin]
    target = plone
    """,
)
